use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Bunce
Dave
Etheridge
Florian
Hunter
Jesse
Justin
Karen
Little
Luehrs
Package
Ragwitz
Rolsky
Stash
Stevan
Tim
XS
autarch
doy
ether
irc
justin
lib
rafl
stevan
